"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveRedeemerWhenValidator = exports.resolveVaultTokenRecordWhenProgrammable = exports.resolveDestinationTokenRecordWhenProgrammable = exports.resolveAuthorizationRulesProgram = exports.resolveSplAtaProgramWhenFungible = exports.resolveVaultTokenWhenFungible = exports.resolveOwnerTokenRecordWhenProgrammable = exports.resolveMasterEditionWhenNonFungible = void 0;
const mpl_toolbox_1 = require("@metaplex-foundation/mpl-toolbox");
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const generated_1 = require("../generated");
const resolveMasterEditionWhenNonFungible = (context, accounts, args, programId, isWritable) => {
    if ((0, mpl_token_metadata_1.isNonFungible)(args.tokenStandard)) {
        return {
            value: (0, mpl_token_metadata_1.findMasterEditionPda)(context, {
                mint: (0, generated_1.expectPublicKey)(accounts.mint.value),
            })[0],
            isWritable,
        };
    }
    return { value: programId, isWritable: false };
};
exports.resolveMasterEditionWhenNonFungible = resolveMasterEditionWhenNonFungible;
const resolveOwnerTokenRecordWhenProgrammable = (context, accounts, args, programId, isWritable) => {
    if ((0, mpl_token_metadata_1.isProgrammable)(args.tokenStandard)) {
        return {
            value: (0, mpl_token_metadata_1.findTokenRecordPda)(context, {
                mint: (0, generated_1.expectPublicKey)(accounts.mint.value),
                token: (0, generated_1.expectPublicKey)(accounts.ownerToken.value),
            })[0],
            isWritable,
        };
    }
    return { value: programId, isWritable: false };
};
exports.resolveOwnerTokenRecordWhenProgrammable = resolveOwnerTokenRecordWhenProgrammable;
const resolveVaultTokenWhenFungible = (context, accounts, args, programId, isWritable) => {
    if ((0, mpl_token_metadata_1.isFungible)(args.tokenStandard)) {
        return {
            value: (0, mpl_toolbox_1.findAssociatedTokenPda)(context, {
                owner: (0, generated_1.expectPublicKey)(accounts.vault.value),
                mint: (0, generated_1.expectPublicKey)(accounts.mint.value),
            })[0],
            isWritable,
        };
    }
    return { value: programId, isWritable: false };
};
exports.resolveVaultTokenWhenFungible = resolveVaultTokenWhenFungible;
const resolveSplAtaProgramWhenFungible = (context, accounts, args, programId, isWritable) => {
    if ((0, mpl_token_metadata_1.isFungible)(args.tokenStandard)) {
        return {
            value: context.programs.getPublicKey('splAssociatedToken', 'ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL'),
            isWritable,
        };
    }
    return { value: programId, isWritable: false };
};
exports.resolveSplAtaProgramWhenFungible = resolveSplAtaProgramWhenFungible;
const resolveAuthorizationRulesProgram = (context, accounts, args, programId, isWritable) => {
    if (accounts.authorizationRules.value) {
        return {
            value: context.programs.getPublicKey('mplTokenAuthRules', 'auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg'),
            isWritable,
        };
    }
    return { value: programId, isWritable: false };
};
exports.resolveAuthorizationRulesProgram = resolveAuthorizationRulesProgram;
const resolveDestinationTokenRecordWhenProgrammable = (context, accounts, args, programId, isWritable) => {
    if ((0, mpl_token_metadata_1.isProgrammable)(args.tokenStandard)) {
        return {
            value: (0, mpl_token_metadata_1.findTokenRecordPda)(context, {
                mint: (0, generated_1.expectPublicKey)(accounts.mint.value),
                token: (0, generated_1.expectPublicKey)(accounts.destinationToken.value),
            })[0],
            isWritable,
        };
    }
    return { value: programId, isWritable: false };
};
exports.resolveDestinationTokenRecordWhenProgrammable = resolveDestinationTokenRecordWhenProgrammable;
const resolveVaultTokenRecordWhenProgrammable = (context, accounts, args, programId, isWritable) => {
    if ((0, mpl_token_metadata_1.isProgrammable)(args.tokenStandard)) {
        return {
            value: (0, mpl_token_metadata_1.findTokenRecordPda)(context, {
                mint: (0, generated_1.expectPublicKey)(accounts.mint.value),
                token: (0, generated_1.expectPublicKey)(accounts.vaultToken.value),
            })[0],
            isWritable,
        };
    }
    return { value: programId, isWritable: false };
};
exports.resolveVaultTokenRecordWhenProgrammable = resolveVaultTokenRecordWhenProgrammable;
const resolveRedeemerWhenValidator = (context, accounts, args, programId, isWritable) => {
    if (accounts.validator.value) {
        return {
            value: (0, generated_1.findRedeemerPda)(context, {
                vault: (0, generated_1.expectPublicKey)(accounts.vault.value),
            })[0],
            isWritable,
        };
    }
    return { value: programId, isWritable: false };
};
exports.resolveRedeemerWhenValidator = resolveRedeemerWhenValidator;
//# sourceMappingURL=resolvers.js.map